# MELI

A small module to try to help Mercado Libre (MeLi) developers and the MeLi community! More docs to come soon, but first we need to have a good working library! 

## Wishlist

* Caching mechanism
* Convert to class
* Automatic refresh of tokens
* Standardise credentials file

## Use

```python
from pymeli import Meli

client = Meli(credentials='credentials.json', token='token.json')

```